==> cloud9-0.10.0-sources.jar: software/amazon/awscdk/services/cloud9/cloudformation/EnvironmentEC2Resource.java <==
package software.amazon.awscdk.services.cloud9.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:41:14.335Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloud9.$Module.class, fqn = "@aws-cdk/aws-cloud9.cloudformation.EnvironmentEC2Resource")
public class EnvironmentEC2Resource extends software.amazon.awscdk.Resource {
    protected EnvironmentEC2Resource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloud9.cloudformation.EnvironmentEC2Resource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::Cloud9::EnvironmentEC2``.
     * @param parent the ``cdk.Construct`` this ``EnvironmentEC2Resource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``EnvironmentEC2Resource``
     */
    public EnvironmentEC2Resource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.cloud9.cloudformation.EnvironmentEC2ResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(@javax.annotation.Nullable final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(properties).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    /**
     * @cloudformation_attribute Arn
     */
    public java.lang.String getEnvironmentEc2Arn() {
        return this.jsiiGet("environmentEc2Arn", java.lang.String.class);
    }

    public java.lang.String getEnvironmentEc2Id() {
        return this.jsiiGet("environmentEc2Id", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute Name
     */
    public java.lang.String getEnvironmentEc2Name() {
        return this.jsiiGet("environmentEc2Name", java.lang.String.class);
    }

    public software.amazon.awscdk.services.cloud9.cloudformation.EnvironmentEC2ResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.cloud9.cloudformation.EnvironmentEC2ResourceProps.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html
     */
    public static interface RepositoryProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
         */
        java.lang.Object getPathComponent();
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
         */
        void setPathComponent(final java.lang.String value);
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
         */
        void setPathComponent(final software.amazon.awscdk.CloudFormationToken value);
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
         */
        java.lang.Object getRepositoryUrl();
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
         */
        void setRepositoryUrl(final java.lang.String value);
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
         */
        void setRepositoryUrl(final software.amazon.awscdk.CloudFormationToken value);

        /**
         * @return a {@link Builder} of {@link RepositoryProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link RepositoryProperty}
         */
        final class Builder {
            private java.lang.Object _pathComponent;
            private java.lang.Object _repositoryUrl;

            /**
             * Sets the value of PathComponent
             * @param value ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
             * @return {@code this}
             */
            public Builder withPathComponent(final java.lang.String value) {
                this._pathComponent = java.util.Objects.requireNonNull(value, "pathComponent is required");
                return this;
            }
            /**
             * Sets the value of PathComponent
             * @param value ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
             * @return {@code this}
             */
            public Builder withPathComponent(final software.amazon.awscdk.CloudFormationToken value) {
                this._pathComponent = java.util.Objects.requireNonNull(value, "pathComponent is required");
                return this;
            }
            /**
             * Sets the value of RepositoryUrl
             * @param value ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
             * @return {@code this}
             */
            public Builder withRepositoryUrl(final java.lang.String value) {
                this._repositoryUrl = java.util.Objects.requireNonNull(value, "repositoryUrl is required");
                return this;
            }
            /**
             * Sets the value of RepositoryUrl
             * @param value ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
             * @return {@code this}
             */
            public Builder withRepositoryUrl(final software.amazon.awscdk.CloudFormationToken value) {
                this._repositoryUrl = java.util.Objects.requireNonNull(value, "repositoryUrl is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link RepositoryProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public RepositoryProperty build() {
                return new RepositoryProperty() {
                    private java.lang.Object $pathComponent = java.util.Objects.requireNonNull(_pathComponent, "pathComponent is required");
                    private java.lang.Object $repositoryUrl = java.util.Objects.requireNonNull(_repositoryUrl, "repositoryUrl is required");

                    @Override
                    public java.lang.Object getPathComponent() {
                        return this.$pathComponent;
                    }

                    @Override
                    public void setPathComponent(final java.lang.String value) {
                        this.$pathComponent = java.util.Objects.requireNonNull(value, "pathComponent is required");
                    }

                    @Override
                    public void setPathComponent(final software.amazon.awscdk.CloudFormationToken value) {
                        this.$pathComponent = java.util.Objects.requireNonNull(value, "pathComponent is required");
                    }

                    @Override
                    public java.lang.Object getRepositoryUrl() {
                        return this.$repositoryUrl;
                    }

                    @Override
                    public void setRepositoryUrl(final java.lang.String value) {
                        this.$repositoryUrl = java.util.Objects.requireNonNull(value, "repositoryUrl is required");
                    }

                    @Override
                    public void setRepositoryUrl(final software.amazon.awscdk.CloudFormationToken value) {
                        this.$repositoryUrl = java.util.Objects.requireNonNull(value, "repositoryUrl is required");
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.cloud9.cloudformation.EnvironmentEC2Resource.RepositoryProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
             */
            @Override
            public java.lang.Object getPathComponent() {
                return this.jsiiGet("pathComponent", java.lang.Object.class);
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
             */
            @Override
            public void setPathComponent(final java.lang.String value) {
                this.jsiiSet("pathComponent", java.util.Objects.requireNonNull(value, "pathComponent is required"));
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
             */
            @Override
            public void setPathComponent(final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("pathComponent", java.util.Objects.requireNonNull(value, "pathComponent is required"));
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
             */
            @Override
            public java.lang.Object getRepositoryUrl() {
                return this.jsiiGet("repositoryUrl", java.lang.Object.class);
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
             */
            @Override
            public void setRepositoryUrl(final java.lang.String value) {
                this.jsiiSet("repositoryUrl", java.util.Objects.requireNonNull(value, "repositoryUrl is required"));
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
             */
            @Override
            public void setRepositoryUrl(final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("repositoryUrl", java.util.Objects.requireNonNull(value, "repositoryUrl is required"));
            }
        }
    }
}

==> cloud9-0.11.0-sources.jar: software/amazon/awscdk/services/cloud9/cloudformation/EnvironmentEC2Resource.java <==
package software.amazon.awscdk.services.cloud9.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloud9-environmentec2.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.7 (build b1c202b)", date = "2018-10-11T17:56:19.828Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloud9.$Module.class, fqn = "@aws-cdk/aws-cloud9.cloudformation.EnvironmentEC2Resource")
public class EnvironmentEC2Resource extends software.amazon.awscdk.Resource {
    protected EnvironmentEC2Resource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloud9.cloudformation.EnvironmentEC2Resource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::Cloud9::EnvironmentEC2``.
     * @param parent the ``cdk.Construct`` this ``EnvironmentEC2Resource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``EnvironmentEC2Resource``
     */
    public EnvironmentEC2Resource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.cloud9.cloudformation.EnvironmentEC2ResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(@javax.annotation.Nullable final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(properties).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    /**
     * @cloudformation_attribute Arn
     */
    public java.lang.String getEnvironmentEc2Arn() {
        return this.jsiiGet("environmentEc2Arn", java.lang.String.class);
    }

    public java.lang.String getEnvironmentEc2Id() {
        return this.jsiiGet("environmentEc2Id", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute Name
     */
    public java.lang.String getEnvironmentEc2Name() {
        return this.jsiiGet("environmentEc2Name", java.lang.String.class);
    }

    public software.amazon.awscdk.services.cloud9.cloudformation.EnvironmentEC2ResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.cloud9.cloudformation.EnvironmentEC2ResourceProps.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html
     */
    public static interface RepositoryProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
         */
        java.lang.Object getPathComponent();
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
         */
        void setPathComponent(final java.lang.String value);
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
         */
        void setPathComponent(final software.amazon.awscdk.Token value);
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
         */
        java.lang.Object getRepositoryUrl();
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
         */
        void setRepositoryUrl(final java.lang.String value);
        /**
         * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
         */
        void setRepositoryUrl(final software.amazon.awscdk.Token value);

        /**
         * @return a {@link Builder} of {@link RepositoryProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link RepositoryProperty}
         */
        final class Builder {
            private java.lang.Object _pathComponent;
            private java.lang.Object _repositoryUrl;

            /**
             * Sets the value of PathComponent
             * @param value ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
             * @return {@code this}
             */
            public Builder withPathComponent(final java.lang.String value) {
                this._pathComponent = java.util.Objects.requireNonNull(value, "pathComponent is required");
                return this;
            }
            /**
             * Sets the value of PathComponent
             * @param value ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
             * @return {@code this}
             */
            public Builder withPathComponent(final software.amazon.awscdk.Token value) {
                this._pathComponent = java.util.Objects.requireNonNull(value, "pathComponent is required");
                return this;
            }
            /**
             * Sets the value of RepositoryUrl
             * @param value ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
             * @return {@code this}
             */
            public Builder withRepositoryUrl(final java.lang.String value) {
                this._repositoryUrl = java.util.Objects.requireNonNull(value, "repositoryUrl is required");
                return this;
            }
            /**
             * Sets the value of RepositoryUrl
             * @param value ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
             * @return {@code this}
             */
            public Builder withRepositoryUrl(final software.amazon.awscdk.Token value) {
                this._repositoryUrl = java.util.Objects.requireNonNull(value, "repositoryUrl is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link RepositoryProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public RepositoryProperty build() {
                return new RepositoryProperty() {
                    private java.lang.Object $pathComponent = java.util.Objects.requireNonNull(_pathComponent, "pathComponent is required");
                    private java.lang.Object $repositoryUrl = java.util.Objects.requireNonNull(_repositoryUrl, "repositoryUrl is required");

                    @Override
                    public java.lang.Object getPathComponent() {
                        return this.$pathComponent;
                    }

                    @Override
                    public void setPathComponent(final java.lang.String value) {
                        this.$pathComponent = java.util.Objects.requireNonNull(value, "pathComponent is required");
                    }

                    @Override
                    public void setPathComponent(final software.amazon.awscdk.Token value) {
                        this.$pathComponent = java.util.Objects.requireNonNull(value, "pathComponent is required");
                    }

                    @Override
                    public java.lang.Object getRepositoryUrl() {
                        return this.$repositoryUrl;
                    }

                    @Override
                    public void setRepositoryUrl(final java.lang.String value) {
                        this.$repositoryUrl = java.util.Objects.requireNonNull(value, "repositoryUrl is required");
                    }

                    @Override
                    public void setRepositoryUrl(final software.amazon.awscdk.Token value) {
                        this.$repositoryUrl = java.util.Objects.requireNonNull(value, "repositoryUrl is required");
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.cloud9.cloudformation.EnvironmentEC2Resource.RepositoryProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
             */
            @Override
            public java.lang.Object getPathComponent() {
                return this.jsiiGet("pathComponent", java.lang.Object.class);
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
             */
            @Override
            public void setPathComponent(final java.lang.String value) {
                this.jsiiSet("pathComponent", java.util.Objects.requireNonNull(value, "pathComponent is required"));
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.PathComponent``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-pathcomponent
             */
            @Override
            public void setPathComponent(final software.amazon.awscdk.Token value) {
                this.jsiiSet("pathComponent", java.util.Objects.requireNonNull(value, "pathComponent is required"));
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
             */
            @Override
            public java.lang.Object getRepositoryUrl() {
                return this.jsiiGet("repositoryUrl", java.lang.Object.class);
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
             */
            @Override
            public void setRepositoryUrl(final java.lang.String value) {
                this.jsiiSet("repositoryUrl", java.util.Objects.requireNonNull(value, "repositoryUrl is required"));
            }

            /**
             * ``EnvironmentEC2Resource.RepositoryProperty.RepositoryUrl``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloud9-environmentec2-repository.html#cfn-cloud9-environmentec2-repository-repositoryurl
             */
            @Override
            public void setRepositoryUrl(final software.amazon.awscdk.Token value) {
                this.jsiiSet("repositoryUrl", java.util.Objects.requireNonNull(value, "repositoryUrl is required"));
            }
        }
    }
}
